Struct ParameterCollection

pub(crate) struct ParameterCollection {
    name: CapeStringImpl,
    description: CapeStringImpl,
    parameters: Vec<CapeParameter>,
    shared_unit_data: Rc<RefCell<SharedUnitData>>,
    parameter_name_map: CapeOpenMap<usize>,
    cobia_object_data: ParameterCollectionCobiaObjectData,
}
A collection of parameters for the distillation shortcut unit.

This collection implements the ICapeIdentification and ICapeCollection<ICapeParameter> interfaces and provides methods to manage parameters associated with the unit.

Fields

name: CapeStringImpl

The name of the parameter collection.

description: CapeStringImpl

The description of the parameter collection.

parameters: Vec<CapeParameter>

The parameters in the collection.

shared_unit_data: Rc<RefCell<SharedUnitData>>

Shared data for the unit, allowing access to common properties.

parameter_name_map: CapeOpenMap<usize>

A map to quickly access parameters by their names.

cobia_object_data: ParameterCollectionCobiaObjectData

Cobia object data for this object, which contains generated code to provide the native COBIA interfaces

Implementations

Source

impl ParameterCollection

fn create_instance( _parameter_collection_boxed_ptr: *mut *mut ICapeInterface, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> CapeResult

pub(crate) fn create<T: CapeSmartPointer>( shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> T

Create a new instance of the object and return a smart pointer to it

This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.

pub(crate) fn try_create<T: CapeSmartPointer>( shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> Result<T, COBIAError>

Create a new instance of the object and return a smart pointer to it

This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.

pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self

Get a reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self

Get a mutable reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

Source

impl ParameterCollection

fn new(shared_unit_data: Rc<RefCell<SharedUnitData>>) -> Self

Creates a new ParameterCollection for the distillation shortcut unit.

Arguments
  • shared_unit_data - A reference to shared data for the unit, which contains common properties.
Returns

A new instance of ParameterCollection initialized with the provided shared data.

pub(crate) fn add_parameter<T: CapeSmartPointer>(&mut self, parameter: T)

Adds a parameter to the collection.

The parameter’s name is cached for quick look-ups by name.

Arguments
  • parameter - A smart pointer to the parameter to be added.
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut CapeParameter>

Obtain an iterator to iterate over the parameters in the collection.

Returns

An iterator that yields references to the parameters in the collection.