pub(crate) struct ParameterCollection {
name: CapeStringImpl,
description: CapeStringImpl,
parameters: Vec<CapeParameter>,
shared_unit_data: Rc<RefCell<SharedUnitData>>,
parameter_name_map: CapeOpenMap<usize>,
cobia_object_data: ParameterCollectionCobiaObjectData,
}Expand description
A collection of parameters for the distillation shortcut unit.
This collection implements the ICapeIdentification and ICapeCollection<ICapeParameter> interfaces
and provides methods to manage parameters associated with the unit.
Fields
name: CapeStringImplThe name of the parameter collection.
description: CapeStringImplThe description of the parameter collection.
parameters: Vec<CapeParameter>The parameters in the collection.
Shared data for the unit, allowing access to common properties.
parameter_name_map: CapeOpenMap<usize>A map to quickly access parameters by their names.
cobia_object_data: ParameterCollectionCobiaObjectDataCobia object data for this object, which contains generated code to provide the native COBIA interfaces
Implementations
Sourceimpl ParameterCollection
impl ParameterCollection
fn create_instance( _parameter_collection_boxed_ptr: *mut *mut ICapeInterface, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> CapeResult
Sourcepub(crate) fn create<T: CapeSmartPointer>(
shared_unit_data: Rc<RefCell<SharedUnitData>>,
) -> T
pub(crate) fn create<T: CapeSmartPointer>( shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> T
Create a new instance of the object and return a smart pointer to it
This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.
Sourcepub(crate) fn try_create<T: CapeSmartPointer>(
shared_unit_data: Rc<RefCell<SharedUnitData>>,
) -> Result<T, COBIAError>
pub(crate) fn try_create<T: CapeSmartPointer>( shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> Result<T, COBIAError>
Create a new instance of the object and return a smart pointer to it
This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.
Sourcepub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self
pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self
Get a reference to the object
Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows
Safety
The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.
Sourcepub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>(
smart_pointer: &mut T,
) -> &mut Self
pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self
Get a mutable reference to the object
Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows
Safety
This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.
Sourceimpl ParameterCollection
impl ParameterCollection
Sourcefn new(shared_unit_data: Rc<RefCell<SharedUnitData>>) -> Self
fn new(shared_unit_data: Rc<RefCell<SharedUnitData>>) -> Self
Sourcepub(crate) fn add_parameter<T: CapeSmartPointer>(&mut self, parameter: T)
pub(crate) fn add_parameter<T: CapeSmartPointer>(&mut self, parameter: T)
Adds a parameter to the collection.
The parameter’s name is cached for quick look-ups by name.
Arguments
parameter- A smart pointer to the parameter to be added.